@@ -710,7 +710,8 @@ function PrintHexPacketPayload ( $encoded_payload, $output_type )
 function PrintCleanHexPacketPayload( $encoded_payload, $output_type )
 {
      $len = strlen($encoded_payload);
-
+     $s = '';
+     $count = 0;
      for ($i = 0; $i < $len; $i += 2 )
      {
          /* dump the ASCII characters */
@@ -732,9 +733,7 @@ function PrintCleanHexPacketPayload( $encoded_payload, $output_type )
              $s .= $s_tmp;
              $count = 0;
          }
-
      }
-
      return $s;
 }
 
@@ -763,7 +762,7 @@ function PrintPacketPayload($data, $encode_type, $output_type)
          $payload = PrintBase64PacketPayload($data, $output_type);
      else if ($encode_type == "0" )
      {
-         if ( ($_GET[asciiclean] == 1) || ( ($_COOKIE[asciiclean] == "clean") && (!isset($_GET[asciiclean])) ) )
+         if ( isset($_GET['asciiclean']) && ($_GET['asciiclean'] == 1) || ( (isset($_COOKIE['asciiclean']) && $_COOKIE['asciiclean'] == "clean") && (!isset($_GET['asciiclean'])) ) )
 	 {
 	    // Print clean ascii display
             $payload = PrintCleanHexPacketPayload($data, $output_type);
