@@ -475,6 +475,8 @@ function UpdateAlertCache($db)
         $archive_ccid_lst = $db2->baseExecute("SELECT MAX(cid) FROM acid_event WHERE sid='".$sid."'"); 
         $archive_ccid_row = $archive_ccid_lst->baseFetchRow();
         $archive_ccid = $archive_ccid_row[0];
+		$archive_ccid_lst->baseFreeRows();
+		$db2->baseClose();
         if ( $archive_ccid == NULL ) $archive_ccid = 0;
       } else {
         $archive_ccid = 0; 
