@@ -144,6 +144,8 @@ DEFINE('_ROLEMAN','Gestion des Rles');
 // Role Management
 DEFINE('_LISTR','Liste des Rles');
 // List Roles
+DEFINE('_LOGOUT','Logout');
+// Logout
 DEFINE('_CREATER','Crer un Rle');
 // Create a Role
 DEFINE('_LISTALL','Tout Lister');
